==> puppet-module-barbican_19.4.0.orig.tar.xz: puppet-module-barbican-19.4.0/spec/classes/barbican_policy_spec.rb <==
require 'spec_helper'

describe 'barbican::policy' do
  shared_examples 'barbican::policy' do

    context 'setup policy with parameters' do
      let :params do
        {
          :enforce_scope        => false,
          :enforce_new_defaults => false,
          :policy_path          => '/etc/barbican/policy.yaml',
          :policy_dirs          => '/etc/barbican/policy.d',
          :policies             => {
            'context_is_admin' => {
              'key'   => 'context_is_admin',
              'value' => 'foo:bar'
            }
          }
        }
      end

      it 'set up the policies' do
        is_expected.to contain_openstacklib__policy('/etc/barbican/policy.yaml').with(
          :policies     => {
            'context_is_admin' => {
              'key'   => 'context_is_admin',
              'value' => 'foo:bar'
            }
          },
          :policy_path  => '/etc/barbican/policy.yaml',
          :file_user    => 'root',
          :file_group   => 'barbican',
          :file_format  => 'yaml',
          :purge_config => false,
        )
        is_expected.to contain_oslo__policy('barbican_config').with(
          :enforce_scope        => false,
          :enforce_new_defaults => false,
          :policy_file          => '/etc/barbican/policy.yaml',
          :policy_dirs          => '/etc/barbican/policy.d',
        )
      end
    end

    context 'with empty policies and purge_config enabled' do
      let :params do
        {
          :enforce_scope        => false,
          :enforce_new_defaults => false,
          :policy_path          => '/etc/barbican/policy.yaml',
          :policies             => {},
          :purge_config         => true,
        }
      end

      it 'set up the policies' do
        is_expected.to contain_openstacklib__policy('/etc/barbican/policy.yaml').with(
          :policies     => {},
          :policy_path  => '/etc/barbican/policy.yaml',
          :file_user    => 'root',
          :file_group   => 'barbican',
          :file_format  => 'yaml',
          :purge_config => true,
        )
        is_expected.to contain_oslo__policy('barbican_config').with(
          :enforce_scope        => false,
          :enforce_new_defaults => false,
          :policy_file          => '/etc/barbican/policy.yaml',
        )
      end
    end
  end

  on_supported_os({
    :supported_os => OSDefaults.get_supported_os
  }).each do |os,facts|
    context "on #{os}" do
      let (:facts) do
        facts.merge!(OSDefaults.get_facts())
      end

      it_behaves_like 'barbican::policy'
    end
  end
end

==> puppet-module-barbican_23.0.0.orig.tar.xz: puppet-module-barbican-23.0.0/spec/classes/barbican_policy_spec.rb <==
require 'spec_helper'

describe 'barbican::policy' do
  shared_examples 'barbican::policy' do

    context 'setup policy with parameters' do
      let :params do
        {
          :enforce_scope        => false,
          :enforce_new_defaults => false,
          :policy_path          => '/etc/barbican/policy.yaml',
          :policy_default_rule  => 'default',
          :policy_dirs          => '/etc/barbican/policy.d',
          :policies             => {
            'context_is_admin' => {
              'key'   => 'context_is_admin',
              'value' => 'foo:bar'
            }
          }
        }
      end

      it 'set up the policies' do
        is_expected.to contain_openstacklib__policy('/etc/barbican/policy.yaml').with(
          :policies     => {
            'context_is_admin' => {
              'key'   => 'context_is_admin',
              'value' => 'foo:bar'
            }
          },
          :policy_path  => '/etc/barbican/policy.yaml',
          :file_user    => 'root',
          :file_group   => 'barbican',
          :file_format  => 'yaml',
          :purge_config => false,
          :tag          => 'barbican',
        )
        is_expected.to contain_oslo__policy('barbican_config').with(
          :enforce_scope        => false,
          :enforce_new_defaults => false,
          :policy_file          => '/etc/barbican/policy.yaml',
          :policy_default_rule  => 'default',
          :policy_dirs          => '/etc/barbican/policy.d',
        )
      end
    end

    context 'with empty policies and purge_config enabled' do
      let :params do
        {
          :enforce_scope        => false,
          :enforce_new_defaults => false,
          :policy_path          => '/etc/barbican/policy.yaml',
          :policies             => {},
          :purge_config         => true,
        }
      end

      it 'set up the policies' do
        is_expected.to contain_openstacklib__policy('/etc/barbican/policy.yaml').with(
          :policies     => {},
          :policy_path  => '/etc/barbican/policy.yaml',
          :file_user    => 'root',
          :file_group   => 'barbican',
          :file_format  => 'yaml',
          :purge_config => true,
          :tag          => 'barbican',
        )
        is_expected.to contain_oslo__policy('barbican_config').with(
          :enforce_scope        => false,
          :enforce_new_defaults => false,
          :policy_file          => '/etc/barbican/policy.yaml',
        )
      end
    end
  end

  on_supported_os({
    :supported_os => OSDefaults.get_supported_os
  }).each do |os,facts|
    context "on #{os}" do
      let (:facts) do
        facts.merge!(OSDefaults.get_facts())
      end

      it_behaves_like 'barbican::policy'
    end
  end
end
